@@ -1,7 +1,12 @@
 from .const import VERSION
-from .gql_handler import *
-from datetime import datetime
 from .exception_classes import LoginError
+from .gql_handler import *
+
+from datetime import datetime
+
+import logging
+
+_LOGGER = logging.getLogger(__name__)
 
 class PyXploraApi:
     def __init__(self, countrycode: str, phoneNumber: str, password: str, userLang: str, timeZone: str, childPhoneNumber=[]) -> None:
@@ -125,7 +130,7 @@ class PyXploraApi:
                                 'xcoin': xcoin,
                             })
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = self.contacts
             if (not dataOk):
                 self.__logoff()
@@ -216,7 +221,7 @@ class PyXploraApi:
                             'status': alarm['status'],
                         })
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = self.alarms
             if (not dataOk):
                 self.__logoff()
@@ -258,7 +263,7 @@ class PyXploraApi:
                         self.watch_charging = location_raw['watchLastLocate']['isCharging']
                         self.watch_last_location = location_raw['watchLastLocate']
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = self.watch_location
             if (not dataOk):
                 self.__logoff()
@@ -293,7 +298,7 @@ class PyXploraApi:
                 else:
                     asktrack_raw = WatchOnlineStatus.OFFLINE.value
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = asktrack_raw
             if (not dataOk):
                 self.__logoff()
@@ -334,7 +339,7 @@ class PyXploraApi:
                                 'data_sender_name': chat['data']['sender_name'],
                             })
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = self.chats
             if (not dataOk):
                 self.__logoff()
@@ -384,7 +389,7 @@ class PyXploraApi:
                             'address': safeZone['address'],
                         })
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = self.safe_zones
             if (not dataOk):
                 self.__logoff()
@@ -420,7 +425,7 @@ class PyXploraApi:
                             'status': sientTime['status'],
                         })
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = self.school_silent_mode
             if (not dataOk):
                 self.__logoff()
@@ -443,7 +448,7 @@ class PyXploraApi:
                 if 'setEnableSilentTime' in enable_raw:
                     _raw = enable_raw['setEnableSilentTime']
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = _raw
             if (not dataOk):
                 self.__logoff()
@@ -466,7 +471,7 @@ class PyXploraApi:
                 if 'setEnableSilentTime' in disable_raw:
                     _raw = disable_raw['setEnableSilentTime']
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = _raw
             if (not dataOk):
                 self.__logoff()
@@ -500,7 +505,7 @@ class PyXploraApi:
                 if 'modifyAlarm' in enable_raw:
                     _raw = enable_raw['modifyAlarm']
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = _raw
             if (not dataOk):
                 self.__logoff()
@@ -523,7 +528,7 @@ class PyXploraApi:
                 if 'modifyAlarm' in disable_raw:
                     _raw = disable_raw['modifyAlarm']
             except Exception as error:
-                print(error)
+                _LOGGER.debug(error)
             dataOk = _raw
             if (not dataOk):
                 self.__logoff()
